@@ -292,8 +292,7 @@ class Client(commandServer, encrypt, Desktop):
         else:
             nomapposix = ",nomapposix"
         cache_method = self.clVars.Get('cl_cifs_cache')
-        domain = self.clVars.Get('cl_remote_domain') or \
-            self.get_server_domainname(host)
+        domain = self.get_server_domainname(host)
         if not uid is None:
             # mount by uid
             p = process(mountCmd, "-t", "cifs", "-o",
@@ -312,6 +311,9 @@ class Client(commandServer, encrypt, Desktop):
             return p.success()
 
     def get_server_domainname(self, host):
+        vardomain = self.clVars.Get('cl_remote_domain')
+        if vardomain:
+            return vardomain
         if host not in self.domainnames:
             try:
                 self.domainnames[host] = Samba().get_server_domainname(host)
