@@ -22,8 +22,10 @@ from calculate.lib.datavars import (Variable, VariableError, ReadonlyVariable,
                                     ReadonlyTableVariable, FieldValue,
                                     HumanReadable)
 from calculate.lib.cl_ini_parser import iniParser
-from calculate.lib.utils.files import (isMount, readFile, find,
+import calculate.lib.utils.device as device
+from calculate.lib.utils.files import (readFile, find,
                                        FindFileType)
+from calculate.lib.utils.mount import isMount
 from calculate.lib.utils.common import getValueFromCmdLine, CmdlineParams
 from calculate.lib.utils.portage import isPkgInstalled
 from calculate.lib.variables import user
@@ -50,6 +52,11 @@ class VariableClRemoteHost(Variable):
     """
     value = ""
 
+class VariableClRemoteDomain(Variable):
+    """
+    Имя домена 
+    """
+    value = ""
 
 class VariableClRemoteHostNew(Variable):
     """
@@ -734,7 +741,7 @@ class VariableClCifsVer(ReadonlyVariable):
     """
 
     def get(self):
-        return readFile("/sys/module/cifs/version")
+        return device.sysfs.read(device.sysfs.Path.Module, "cifs/version")
 
 
 class VariableClCifsCache(Variable):
